import threading
from collections import OrderedDict
from datetime import timedelta

from yamcs.core.exceptions import YamcsError
from yamcs.core.helpers import parse_isostring, parse_value
from yamcs.model import Event
from yamcs.protobuf.alarms import alarms_pb2
from yamcs.protobuf.pvalue import pvalue_pb2


def _parse_alarm(proto):
    """Converts a protobuf alarm to a specific Alarm implementation."""
    if proto.type == alarms_pb2.PARAMETER:
        return ParameterAlarm(proto)
    if proto.type == alarms_pb2.EVENT:
        return EventAlarm(proto)
    raise YamcsError('Unexpected type ' + proto.type)


class Acknowledgment(object):

    def __init__(self, name, time, status, message):
        self.name = name
        """Name of this acknowledgment."""

        self.time = time
        """Last update time of this acknowledgment."""

        self.status = status
        """Status of this acknowlegment."""

        self.message = message
        """Message of this acknowledgment."""

    def is_terminated(self):
        return self.status and self.status != 'SCHEDULED' and self.status != 'PENDING'

    def __repr__(self):
        return '{}: {}'.format(self.name, self.status)

    def __str__(self):
        return self.__repr__()


class CommandHistory(object):

    def __init__(self, proto):

        self.generation_time = parse_isostring(proto.generationTimeUTC)
        """
        The generation time as set by Yamcs

        :type: :class:`~datetime.datetime`
        """

        self._commandId = proto.commandId
        self.attributes = OrderedDict()
        self._update(proto.attr)

    @property
    def name(self):
        """Name of the command."""
        return self._commandId.commandName

    @property
    def origin(self):
        """
        The origin of this command. This is often empty, but may
        also be a hostname.
        """
        if self._commandId.HasField('origin'):
            return self._commandId.origin
        return None

    @property
    def sequence_number(self):
        """
        The sequence number of this command. This is the sequence
        number assigned by the issuing client.
        """
        if self._commandId.HasField('sequenceNumber'):
            return self._commandId.sequenceNumber
        return None

    @property
    def username(self):
        """Username of the issuer."""
        return self.attributes.get('username')

    @property
    def source(self):
        """String representation of the command."""
        return self.attributes.get('source')

    @property
    def binary(self):
        """Binary representation of the command."""
        return self.attributes.get('binary')

    def is_complete(self):
        """
        Returns whether this command is complete. A command
        can be completed, yet still failed.
        """
        ack = self._assemble_ack('CommandComplete')
        return ack and (ack.status == 'OK' or ack.status == 'NOK')

    def is_success(self):
        """
        Returns True if the command has completed successfully.
        """
        ack = self._assemble_ack('CommandComplete')
        return ack and ack.status == 'OK'

    def is_failure(self):
        """
        Returns True if the command failed.
        """
        ack = self._assemble_ack('CommandComplete')
        return ack and ack.status == 'NOK'

    @property
    def error(self):
        """Error message in case the command failed."""
        ack = self._assemble_ack('CommandComplete')
        if ack and ack.status == 'NOK':
            return ack.message
        return None

    @property
    def comment(self):
        """Optional user comment attached when issuing the command."""
        return self.attributes.get('comment')

    @property
    def acknowledgments(self):
        """
        All acknowledgments by name.

        :return: Acknowledgments keyed by name.
        :rtype: ~collections.OrderedDict
        """
        acks = OrderedDict()
        for name, _ in self.attributes.items():
            if name.startswith('CommandComplete'):
                continue
            if name.startswith('TransmissionConstraints'):
                continue
            if name.endswith('_Status'):
                ack = self._assemble_ack(name[:-7])
                if ack:
                    acks[ack.name] = ack

        return acks

    def _assemble_ack(self, name):
        time = self.attributes.get(name + '_Time')
        status = self.attributes.get(name + '_Status')
        message = self.attributes.get(name + '_Message')
        if time and status:
            return Acknowledgment(name, time, status, message)
        return None

    def _update(self, proto):
        for attr in proto:
            value = parse_value(attr.value)
            self.attributes[attr.name] = value

    def __str__(self):
        acks = ', '.join(ack.__repr__() for _, ack in self.acknowledgments.items())
        return '{} [{}]'.format(self.name, acks)


class IssuedCommand(object):

    def __init__(self, proto, client):
        self._proto = proto
        self._client = client

    @property
    def id(self):
        """
        A unique identifier for this command.
        """
        return self._proto.id

    @property
    def name(self):
        """
        The fully-qualified name of this command.
        """
        if self._proto.HasField('commandName'):
            return self._proto.commandName
        return None

    @property
    def generation_time(self):
        """
        The generation time as set by Yamcs.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('generationTime'):
            return parse_isostring(self._proto.generationTime)
        return None

    @property
    def username(self):
        """The username of the issuer."""
        if self._proto.HasField('username'):
            return self._proto.username
        return None

    @property
    def queue(self):
        """The name of the queue that this command was assigned to."""
        if self._proto.HasField('queue'):
            return self._proto.queue
        return None

    @property
    def origin(self):
        """
        The origin of this command. Usually the IP address of the issuer.
        """
        if self._proto.HasField('origin'):
            return self._proto.origin
        return None

    @property
    def sequence_number(self):
        """
        The sequence number of this command. This is the sequence
        number assigned by the issuing client.
        """
        if self._proto.HasField('sequenceNumber'):
            return self._proto.sequenceNumber
        return None

    @property
    def source(self):
        """String representation of this command."""
        if self._proto.HasField('source'):
            return self._proto.source
        return None

    @property
    def hex(self):
        """Hexadecimal string representation of this command."""
        if self._proto.HasField('hex'):
            return self._proto.hex
        return None

    @property
    def binary(self):
        """Binary representation of this command."""
        if self._proto.HasField('binary'):
            return self._proto.binary
        return None

    def __str__(self):
        return '{} {}'.format(self.generation_time, self.source)


class MonitoredCommand(IssuedCommand):
    """
    Represent an instance of an issued command that is updated
    throughout the acknowledgment process.

    Objects of this class are owned by a :class:`.CommandConnection` instance.
    """

    def __init__(self, proto, client):
        super(MonitoredCommand, self).__init__(proto, client)
        self._cmdhist = None
        self._completed = threading.Event()
        self._ack_events = {}

    def _process_cmdhist(self, cmdhist):
        self._cmdhist = cmdhist
        if self.is_complete():
            self._completed.set()
        for name, ack in self.acknowledgments.items():
            event = self._ack_events.setdefault(name, threading.Event())
            if ack.is_terminated():
                event.set()

    @property
    def attributes(self):
        if self._cmdhist:
            return self._cmdhist.attributes
        return OrderedDict()

    def is_complete(self):
        """
        Returns whether this command is complete. A command
        can be completed, yet still failed.
        """
        ack = self._assemble_ack('CommandComplete')
        return ack and (ack.status == 'OK' or ack.status == 'NOK')

    def await_complete(self, timeout=None):
        """
        Wait for the command to be completed.
        """
        self._wait_on_signal(self._completed, timeout)

    def await_acknowledgment(self, name, timeout=None):
        """
        Waits for the result of a specific acknowledgment.

        :param str name: The name of the acknowledgment. Standard names are
                         ``Acknowledge_Queued``, ``Acknowledge_Released``
                         and ``Acknowledge_Sent``. Others depend on
                         specific link types.

        :rtype: .Acknowledgment
        """
        event = self._ack_events.setdefault(name, threading.Event())
        self._wait_on_signal(event, timeout)
        return self.acknowledgments.get(name)

    def _wait_on_signal(self, event, timeout=None):
        # Wait until the future is done. We do not use wait() without timeout
        # because on Python 2.x this does not generate ``KeyboardInterrupt``.
        # https://bugs.python.org/issue8844
        if timeout is not None:
            if not event.wait(timeout=timeout):
                # Remark that a timeout does *not* mean that the underlying
                # work is canceled.
                raise TimeoutError('Timed out.')
        else:
            # The actual timeout value does not have any impact
            while not event.wait(timeout=10):
                pass  # tick

    @property
    def error(self):
        """Error message in case the command failed."""
        ack = self._assemble_ack('CommandComplete')
        if ack and ack.status == 'NOK':
            return ack.message
        return None

    @property
    def comment(self):
        """Optional user comment attached when issuing the command."""
        return self.attributes.get('comment')

    @property
    def acknowledgments(self):
        """
        All acknowledgments by name.

        :return: Acknowledgments keyed by name.
        :rtype: ~collections.OrderedDict
        """
        acks = OrderedDict()
        for name, _ in self.attributes.items():
            if name.startswith('CommandComplete'):
                continue
            if name.startswith('TransmissionConstraints'):
                continue
            if name.endswith('_Status'):
                ack = self._assemble_ack(name[:-7])
                if ack:
                    acks[ack.name] = ack

        return acks

    def _assemble_ack(self, name):
        time = self.attributes.get(name + '_Time')
        status = self.attributes.get(name + '_Status')
        message = self.attributes.get(name + '_Message')
        if time and status:
            return Acknowledgment(name, time, status, message)
        return None

    def _update(self, proto):
        for attr in proto:
            value = parse_value(attr.value)
            self.attributes[attr.name] = value

    def __str__(self):
        acks = ', '.join(ack.__repr__() for _, ack in self.acknowledgments.items())
        return '{} [{}]'.format(self.name, acks)


class AlarmUpdate(object):
    """
    Object received through callbacks when subscribing to alarm updates.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def update_type(self):
        """Type of update."""
        return alarms_pb2.AlarmNotificationType.Name(self._proto.type)

    @property
    def alarm(self):
        """
        Latest alarm state.

        :type: :class:`.Alarm`
        """
        return _parse_alarm(self._proto)

    def __str__(self):
        return '[{}] {}'.format(self.update_type, self.alarm)


class Alarm(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Fully-qualified name of the source of this alarm."""
        if self._proto.id.HasField('namespace'):
            return self._proto.id.namespace + '/' + self._proto.id.name
        return self._proto.id.name

    @property
    def trigger_time(self):
        """
        Processor time when the alarm was triggered.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('triggerTime'):
            return parse_isostring(self._proto.triggerTime)
        return None

    @property
    def severity(self):
        if self._proto.HasField('severity'):
            return alarms_pb2.AlarmSeverity.Name(self._proto.severity)
        return None

    @property
    def sequence_number(self):
        """
        Sequence number for this specific alarm instance. This allows ensuring
        that operations (such as acknowledgment) are done on the expected alarm
        instance.
        """
        if self._proto.HasField('seqNum'):
            return self._proto.seqNum
        return None

    @property
    def is_ok(self):
        """
        True if this alarm is currently 'inactive'.

        For a non-latching alarm this is identical to :meth:`is_process_ok`. A
        latching alarm is only OK if it has returned to normal and was
        acknowledged.
        """
        return not self._proto.triggered

    @property
    def is_process_ok(self):
        """
        True if the process that caused this alarm is OK. For example:
        parameter back within limits.

        For a non-latching alarm this is identical to :meth:`is_ok`.
        """
        return self._proto.processOK

    @property
    def is_latching(self):
        """
        True if this is a latching alarm. A latching alarm returns to
        normal only when the operator resets it
        """
        return self._proto.HasField('latching') and self._proto.latching

    @property
    def is_latched(self):
        """
        True if this alarm is currently latched.
        """
        return self.is_latching and self.is_process_ok and not self.is_ok

    @property
    def is_acknowledged(self):
        """True if this alarm has been acknowledged."""
        return self._proto.acknowledged

    @property
    def acknowledged_by(self):
        """Username of the acknowledger."""
        if (self.is_acknowledged and
                self._proto.acknowledgeInfo.HasField('acknowledgedBy')):
            return self._proto.acknowledgeInfo.acknowledgedBy
        return None

    @property
    def acknowledge_message(self):
        """Comment provided when acknowledging the alarm."""
        if (self.is_acknowledged and
                self._proto.acknowledgeInfo.HasField('acknowledgeMessage')):
            return self._proto.acknowledgeInfo.acknowledgeMessage
        return None

    @property
    def acknowledge_time(self):
        """
        Processor time when the alarm was acknowledged.

        :type: :class:`~datetime.datetime`
        """
        if (self.is_acknowledged and
                self._proto.acknowledgeInfo.HasField('acknowledgeTime')):
            return parse_isostring(self._proto.acknowledgeInfo.acknowledgeTime)
        return None

    @property
    def is_shelved(self):
        """True if this alarm has been shelved."""
        return self._proto.HasField('shelveInfo')

    @property
    def violation_count(self):
        """
        Number of violating samples while this alarm is active.
        """
        if self._proto.HasField('violations'):
            return self._proto.violations
        return None

    @property
    def count(self):
        """
        Total number of samples while this alarm is active.
        """
        if self._proto.HasField('count'):
            return self._proto.count
        return None

    def __str__(self):
        return '{} ({} violations)'.format(
            self.name, self.violation_count)


class ParameterAlarm(Alarm):
    """
    An alarm triggered by a parameter that went out of limits.
    """

    @property
    def trigger_value(self):
        """
        Parameter value that originally triggered the alarm

        :type: :class:`.ParameterValue`
        """
        if self._proto.parameterDetail.HasField('triggerValue'):
            return ParameterValue(self._proto.parameterDetail.triggerValue)
        return None

    @property
    def most_severe_value(self):
        """
        First parameter value that invoked the highest severity
        level of this alarm.

        :type: :class:`.ParameterValue`
        """
        if self._proto.parameterDetail.HasField('mostSevereValue'):
            return ParameterValue(self._proto.parameterDetail.mostSevereValue)
        return None

    @property
    def current_value(self):
        """
        Latest parameter value for this alarm.

        :type: :class:`.ParameterValue`
        """
        if self._proto.parameterDetail.HasField('currentValue'):
            return ParameterValue(self._proto.parameterDetail.currentValue)
        return None


class EventAlarm(Alarm):
    """
    An alarm triggered by an event.
    """

    @property
    def trigger_event(self):
        """
        Event that originally triggered the alarm

        :type: :class:`.Event`
        """
        if self._proto.eventDetail.HasField('triggerEvent'):
            return Event(self._proto.eventDetail.triggerEvent)
        return None

    @property
    def most_severe_event(self):
        """
        First event that invoked the highest severity level
        of this alarm

        :type: :class:`.Event`
        """
        if self._proto.eventDetail.HasField('mostSevereEvent'):
            return Event(self._proto.eventDetail.mostSevereEvent)
        return None

    @property
    def current_event(self):
        """
        Latest event for this alarm

        :type: :class:`.Event`
        """
        if self._proto.eventDetail.HasField('currentEvent'):
            return Event(self._proto.eventDetail.currentEvent)
        return None


class ParameterData(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def parameters(self):
        """
        :type: List[:class:`.ParameterValue`]
        """
        return [ParameterValue(p) for p in self._proto.parameter]


class ParameterValue(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """
        An identifying name for the parameter value. Typically this is the
        fully-qualified XTCE name, but it may also be an alias depending
        on how the parameter update was requested.
        """
        if self._proto.id.namespace:
            return self._proto.id.namespace + '/' + self._proto.id.name
        return self._proto.id.name

    @property
    def generation_time(self):
        """
        The time when the parameter was generated. If the parameter
        was extracted from a packet, this usually returns the packet time.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('generationTimeUTC'):
            return parse_isostring(self._proto.generationTimeUTC)
        return None

    @property
    def reception_time(self):
        """
        The time when the parameter value was received by Yamcs.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('acquisitionTimeUTC'):
            return parse_isostring(self._proto.acquisitionTimeUTC)
        return None

    @property
    def validity_duration(self):
        """
        How long this parameter value is valid.

        .. note: There is also an option when subscribing to get updated when
                 the parameter values expire.

        :type: :class:`~datetime.timedelta`
        """
        if self._proto.HasField('expireMillis'):
            return timedelta(milliseconds=self._proto.expireMillis)
        return None

    @property
    def raw_value(self):
        """
        The raw (uncalibrated) value.
        """
        if self._proto.HasField('rawValue'):
            return parse_value(self._proto.rawValue)
        return None

    @property
    def eng_value(self):
        """
        The engineering (calibrated) value.
        """
        if self._proto.HasField('engValue'):
            return parse_value(self._proto.engValue)
        return None

    @property
    def monitoring_result(self):
        if self._proto.HasField('monitoringResult'):
            return pvalue_pb2.MonitoringResult.Name(self._proto.monitoringResult)
        return None

    @property
    def range_condition(self):
        """
        If the value is out of limits, this indicates ``LOW`` or ``HIGH``.
        """
        if self._proto.HasField('rangeCondition'):
            return pvalue_pb2.RangeCondition.Name(self._proto.rangeCondition)
        return None

    @property
    def validity_status(self):
        if self._proto.HasField('acquisitionStatus'):
            return pvalue_pb2.AcquisitionStatus.Name(self._proto.acquisitionStatus)
        return None

    @property
    def processing_status(self):
        return self._proto.processingStatus

    def __str__(self):
        line = '{} {} {} {}'.format(self.generation_time, self.name, self.raw_value, self.eng_value)
        if self.monitoring_result:
            line += ' [' + self.monitoring_result + ']'
        return line


class Calibrator(object):
    """
    A calibrator that may be applied to a numeric raw value.

    Two types of calibrators can be applied:

    * Polynomial calibrators apply a polynomial expression of the form:
        `y = a + bx + cx^2 + ...`.

        The `data` argument must be an array of floats ``[a, b, c, ...]``.

    * Spline calibrators interpolate the raw value between a set of points
        which represent a linear curve.

        The `data` argument must be an array of ``[x, y]`` points.
    """

    POLYNOMIAL = 'polynomial'
    SPLINE = 'spline'

    def __init__(self, context, type, data):  # pylint: disable=W0622
        """
        :param str context: Condition under which this calibrator may be
                            applied. The value ``None`` indicates the
                            default calibrator which is only applied if
                            no contextual calibrators match.
        :param str type: One of ``polynomial`` or ``spline``.
        :param data: Calibration definition for the selected type.
        """
        self.context = context
        self.type = type
        self.data = data


class RangeSet(object):
    """
    A set of alarm range that apply in a specific context.
    """

    def __init__(self, context, watch=None, warning=None, distress=None,
                 critical=None, severe=None, min_violations=1):
        """
        :param str context: Condition under which this range set is
                            applicable. The value ``None`` indicates the
                            default range set which is only applicable if
                            no contextual sets match.
        :param (float,float) watch: Range expressed as a tuple ``(lo, hi)``
                                where lo and hi are assumed exclusive.
        :param (float,float) warning: Range expressed as a tuple ``(lo, hi)``
                                  where lo and hi are assumed exclusive.
        :param (float,float) distress: Range expressed as a tuple ``(lo, hi)``
                                   where lo and hi are assumed exclusive.
        :param (float,float) critical: Range expressed as a tuple ``(lo, hi)``
                                   where lo and hi are assumed exclusive.
        :param (float,float) severe: Range expressed as a tuple ``(lo, hi)``
                                 where lo and hi are assumed exclusive.
        :param int min_violations: Minimum violations before an alarm is
                                   generated.
        """
        self.context = context
        self.watch = watch
        self.warning = warning
        self.distress = distress
        self.critical = critical
        self.severe = severe
        self.min_violations = min_violations



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/archive/tag_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/archive/tag_service.proto',
  package='yamcs.protobuf.web',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\017TagServiceProtoP\001'),
  serialized_pb=_b('\n(yamcs/protobuf/archive/tag_service.proto\x12\x12yamcs.protobuf.web\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"x\n\x0fListTagsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\";\n\x10ListTagsResponse\x12\'\n\x03tag\x18\x01 \x03(\x0b\x32\x1a.yamcs.protobuf.ArchiveTag\"]\n\rGetTagRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12+\n\x07tagTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05tagId\x18\x03 \x01(\x05\"s\n\x10\x43reateTagRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05start\x18\x03 \x01(\t\x12\x0c\n\x04stop\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\r\n\x05\x63olor\x18\x06 \x01(\t\"\xad\x01\n\x0e\x45\x64itTagRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12+\n\x07tagTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05tagId\x18\x03 \x01(\x05\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05start\x18\x05 \x01(\t\x12\x0c\n\x04stop\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\r\n\x05\x63olor\x18\x08 \x01(\t\"`\n\x10\x44\x65leteTagRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12+\n\x07tagTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05tagId\x18\x03 \x01(\x05\x32\xff\x04\n\x06TagApi\x12y\n\x08ListTags\x12#.yamcs.protobuf.web.ListTagsRequest\x1a$.yamcs.protobuf.web.ListTagsResponse\"\"\x8a\x92\x03\x1e\n\x1c/api/archive/{instance}/tags\x12}\n\x06GetTag\x12!.yamcs.protobuf.web.GetTagRequest\x1a\x1a.yamcs.protobuf.ArchiveTag\"4\x8a\x92\x03\x30\n./api/archive/{instance}/tags/{tagTime}/{tagId}\x12q\n\tCreateTag\x12$.yamcs.protobuf.web.CreateTagRequest\x1a\x1a.yamcs.protobuf.ArchiveTag\"\"\x8a\x92\x03\x1e\x1a\x1c/api/archive/{instance}/tags\x12\x81\x01\n\tUpdateTag\x12\".yamcs.protobuf.web.EditTagRequest\x1a\x1a.yamcs.protobuf.ArchiveTag\"4\x8a\x92\x03\x30*./api/archive/{instance}/tags/{tagTime}/{tagId}\x12\x83\x01\n\tDeleteTag\x12$.yamcs.protobuf.web.DeleteTagRequest\x1a\x1a.yamcs.protobuf.ArchiveTag\"4\x8a\x92\x03\x30\"./api/archive/{instance}/tags/{tagTime}/{tagId}B\'\n\x12org.yamcs.protobufB\x0fTagServiceProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_LISTTAGSREQUEST = _descriptor.Descriptor(
  name='ListTagsRequest',
  full_name='yamcs.protobuf.web.ListTagsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.ListTagsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.web.ListTagsRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.web.ListTagsRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=274,
)


_LISTTAGSRESPONSE = _descriptor.Descriptor(
  name='ListTagsResponse',
  full_name='yamcs.protobuf.web.ListTagsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='yamcs.protobuf.web.ListTagsResponse.tag', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=335,
)


_GETTAGREQUEST = _descriptor.Descriptor(
  name='GetTagRequest',
  full_name='yamcs.protobuf.web.GetTagRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.GetTagRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tagTime', full_name='yamcs.protobuf.web.GetTagRequest.tagTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tagId', full_name='yamcs.protobuf.web.GetTagRequest.tagId', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=430,
)


_CREATETAGREQUEST = _descriptor.Descriptor(
  name='CreateTagRequest',
  full_name='yamcs.protobuf.web.CreateTagRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.CreateTagRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.web.CreateTagRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.web.CreateTagRequest.start', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.web.CreateTagRequest.stop', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.web.CreateTagRequest.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='yamcs.protobuf.web.CreateTagRequest.color', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=547,
)


_EDITTAGREQUEST = _descriptor.Descriptor(
  name='EditTagRequest',
  full_name='yamcs.protobuf.web.EditTagRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.EditTagRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tagTime', full_name='yamcs.protobuf.web.EditTagRequest.tagTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tagId', full_name='yamcs.protobuf.web.EditTagRequest.tagId', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.web.EditTagRequest.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.web.EditTagRequest.start', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.web.EditTagRequest.stop', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.web.EditTagRequest.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='yamcs.protobuf.web.EditTagRequest.color', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=723,
)


_DELETETAGREQUEST = _descriptor.Descriptor(
  name='DeleteTagRequest',
  full_name='yamcs.protobuf.web.DeleteTagRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.DeleteTagRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tagTime', full_name='yamcs.protobuf.web.DeleteTagRequest.tagTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tagId', full_name='yamcs.protobuf.web.DeleteTagRequest.tagId', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=821,
)

_LISTTAGSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTTAGSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTTAGSRESPONSE.fields_by_name['tag'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVETAG
_GETTAGREQUEST.fields_by_name['tagTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EDITTAGREQUEST.fields_by_name['tagTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DELETETAGREQUEST.fields_by_name['tagTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ListTagsRequest'] = _LISTTAGSREQUEST
DESCRIPTOR.message_types_by_name['ListTagsResponse'] = _LISTTAGSRESPONSE
DESCRIPTOR.message_types_by_name['GetTagRequest'] = _GETTAGREQUEST
DESCRIPTOR.message_types_by_name['CreateTagRequest'] = _CREATETAGREQUEST
DESCRIPTOR.message_types_by_name['EditTagRequest'] = _EDITTAGREQUEST
DESCRIPTOR.message_types_by_name['DeleteTagRequest'] = _DELETETAGREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListTagsRequest = _reflection.GeneratedProtocolMessageType('ListTagsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTAGSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.tag_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListTagsRequest)
  })
_sym_db.RegisterMessage(ListTagsRequest)

ListTagsResponse = _reflection.GeneratedProtocolMessageType('ListTagsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTAGSRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.tag_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListTagsResponse)
  })
_sym_db.RegisterMessage(ListTagsResponse)

GetTagRequest = _reflection.GeneratedProtocolMessageType('GetTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTAGREQUEST,
  '__module__' : 'yamcs.protobuf.archive.tag_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.GetTagRequest)
  })
_sym_db.RegisterMessage(GetTagRequest)

CreateTagRequest = _reflection.GeneratedProtocolMessageType('CreateTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETAGREQUEST,
  '__module__' : 'yamcs.protobuf.archive.tag_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.CreateTagRequest)
  })
_sym_db.RegisterMessage(CreateTagRequest)

EditTagRequest = _reflection.GeneratedProtocolMessageType('EditTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITTAGREQUEST,
  '__module__' : 'yamcs.protobuf.archive.tag_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.EditTagRequest)
  })
_sym_db.RegisterMessage(EditTagRequest)

DeleteTagRequest = _reflection.GeneratedProtocolMessageType('DeleteTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETAGREQUEST,
  '__module__' : 'yamcs.protobuf.archive.tag_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.DeleteTagRequest)
  })
_sym_db.RegisterMessage(DeleteTagRequest)


DESCRIPTOR._options = None

_TAGAPI = _descriptor.ServiceDescriptor(
  name='TagApi',
  full_name='yamcs.protobuf.web.TagApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=824,
  serialized_end=1463,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListTags',
    full_name='yamcs.protobuf.web.TagApi.ListTags',
    index=0,
    containing_service=None,
    input_type=_LISTTAGSREQUEST,
    output_type=_LISTTAGSRESPONSE,
    serialized_options=_b('\212\222\003\036\n\034/api/archive/{instance}/tags'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTag',
    full_name='yamcs.protobuf.web.TagApi.GetTag',
    index=1,
    containing_service=None,
    input_type=_GETTAGREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVETAG,
    serialized_options=_b('\212\222\0030\n./api/archive/{instance}/tags/{tagTime}/{tagId}'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateTag',
    full_name='yamcs.protobuf.web.TagApi.CreateTag',
    index=2,
    containing_service=None,
    input_type=_CREATETAGREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVETAG,
    serialized_options=_b('\212\222\003\036\032\034/api/archive/{instance}/tags'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTag',
    full_name='yamcs.protobuf.web.TagApi.UpdateTag',
    index=3,
    containing_service=None,
    input_type=_EDITTAGREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVETAG,
    serialized_options=_b('\212\222\0030*./api/archive/{instance}/tags/{tagTime}/{tagId}'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTag',
    full_name='yamcs.protobuf.web.TagApi.DeleteTag',
    index=4,
    containing_service=None,
    input_type=_DELETETAGREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVETAG,
    serialized_options=_b('\212\222\0030\"./api/archive/{instance}/tags/{tagTime}/{tagId}'),
  ),
])
_sym_db.RegisterServiceDescriptor(_TAGAPI)

DESCRIPTOR.services_by_name['TagApi'] = _TAGAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/buckets/buckets.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/buckets/buckets.proto',
  package='yamcs.protobuf.buckets',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\014BucketsProtoP\001'),
  serialized_pb=_b('\n$yamcs/protobuf/buckets/buckets.proto\x12\x16yamcs.protobuf.buckets\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\"5\n\x13\x43reateBucketRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\";\n\x13\x44\x65leteBucketRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x12\n\nbucketName\x18\x02 \x01(\t\"L\n\x10GetObjectRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x12\n\nbucketName\x18\x02 \x01(\t\x12\x12\n\nobjectName\x18\x03 \x01(\t\"O\n\x13\x44\x65leteObjectRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x12\n\nbucketName\x18\x02 \x01(\t\x12\x12\n\nobjectName\x18\x03 \x01(\t\"O\n\x13UploadObjectRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x12\n\nbucketName\x18\x02 \x01(\t\x12\x12\n\nobjectName\x18\x03 \x01(\t\"<\n\nBucketInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x12\n\nnumObjects\x18\x03 \x01(\r\"\xae\x01\n\nObjectInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12\x42\n\x08metadata\x18\x04 \x03(\x0b\x32\x30.yamcs.protobuf.buckets.ObjectInfo.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"&\n\x12ListBucketsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"J\n\x13ListBucketsResponse\x12\x33\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.buckets.BucketInfo\"]\n\x12ListObjectsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x12\n\nbucketName\x18\x02 \x01(\t\x12\x11\n\tdelimiter\x18\x03 \x01(\t\x12\x0e\n\x06prefix\x18\x04 \x01(\t\"\\\n\x13ListObjectsResponse\x12\x10\n\x08prefixes\x18\x01 \x03(\t\x12\x33\n\x07objects\x18\x02 \x03(\x0b\x32\".yamcs.protobuf.buckets.ObjectInfo2\xee\x07\n\nBucketsApi\x12\x85\x01\n\x0bListBuckets\x12*.yamcs.protobuf.buckets.ListBucketsRequest\x1a+.yamcs.protobuf.buckets.ListBucketsResponse\"\x1d\x8a\x92\x03\x19\n\x17/api/buckets/{instance}\x12u\n\x0c\x43reateBucket\x12+.yamcs.protobuf.buckets.CreateBucketRequest\x1a\x16.google.protobuf.Empty\" \x8a\x92\x03\x1c\x1a\x17/api/buckets/{instance}:\x01*\x12\x7f\n\x0c\x44\x65leteBucket\x12+.yamcs.protobuf.buckets.DeleteBucketRequest\x1a\x16.google.protobuf.Empty\"*\x8a\x92\x03&\"$/api/buckets/{instance}/{bucketName}\x12\x8c\x01\n\tGetObject\x12(.yamcs.protobuf.buckets.GetObjectRequest\x1a\x13.yamcs.api.HttpBody\"@\x8a\x92\x03<\n:/api/buckets/{instance}/{bucketName}/objects/{objectName*}\x12\x9b\x01\n\x0cUploadObject\x12+.yamcs.protobuf.buckets.UploadObjectRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a;/api/buckets/{instance}/{bucketName}/objects/{objectName**}@\x80\x80\xc0\x02\x12\x9a\x01\n\x0bListObjects\x12*.yamcs.protobuf.buckets.ListObjectsRequest\x1a+.yamcs.protobuf.buckets.ListObjectsResponse\"2\x8a\x92\x03.\n,/api/buckets/{instance}/{bucketName}/objects\x12\x95\x01\n\x0c\x44\x65leteObject\x12+.yamcs.protobuf.buckets.DeleteObjectRequest\x1a\x16.google.protobuf.Empty\"@\x8a\x92\x03<\":/api/buckets/{instance}/{bucketName}/objects/{objectName*}B$\n\x12org.yamcs.protobufB\x0c\x42ucketsProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,])




_CREATEBUCKETREQUEST = _descriptor.Descriptor(
  name='CreateBucketRequest',
  full_name='yamcs.protobuf.buckets.CreateBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.buckets.CreateBucketRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.buckets.CreateBucketRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=201,
)


_DELETEBUCKETREQUEST = _descriptor.Descriptor(
  name='DeleteBucketRequest',
  full_name='yamcs.protobuf.buckets.DeleteBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.buckets.DeleteBucketRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucketName', full_name='yamcs.protobuf.buckets.DeleteBucketRequest.bucketName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=262,
)


_GETOBJECTREQUEST = _descriptor.Descriptor(
  name='GetObjectRequest',
  full_name='yamcs.protobuf.buckets.GetObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.buckets.GetObjectRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucketName', full_name='yamcs.protobuf.buckets.GetObjectRequest.bucketName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectName', full_name='yamcs.protobuf.buckets.GetObjectRequest.objectName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=340,
)


_DELETEOBJECTREQUEST = _descriptor.Descriptor(
  name='DeleteObjectRequest',
  full_name='yamcs.protobuf.buckets.DeleteObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.buckets.DeleteObjectRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucketName', full_name='yamcs.protobuf.buckets.DeleteObjectRequest.bucketName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectName', full_name='yamcs.protobuf.buckets.DeleteObjectRequest.objectName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=421,
)


_UPLOADOBJECTREQUEST = _descriptor.Descriptor(
  name='UploadObjectRequest',
  full_name='yamcs.protobuf.buckets.UploadObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.buckets.UploadObjectRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucketName', full_name='yamcs.protobuf.buckets.UploadObjectRequest.bucketName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectName', full_name='yamcs.protobuf.buckets.UploadObjectRequest.objectName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=502,
)


_BUCKETINFO = _descriptor.Descriptor(
  name='BucketInfo',
  full_name='yamcs.protobuf.buckets.BucketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.buckets.BucketInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='yamcs.protobuf.buckets.BucketInfo.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numObjects', full_name='yamcs.protobuf.buckets.BucketInfo.numObjects', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=564,
)


_OBJECTINFO_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yamcs.protobuf.buckets.ObjectInfo.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.buckets.ObjectInfo.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.buckets.ObjectInfo.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=694,
  serialized_end=741,
)

_OBJECTINFO = _descriptor.Descriptor(
  name='ObjectInfo',
  full_name='yamcs.protobuf.buckets.ObjectInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.buckets.ObjectInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created', full_name='yamcs.protobuf.buckets.ObjectInfo.created', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='yamcs.protobuf.buckets.ObjectInfo.size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yamcs.protobuf.buckets.ObjectInfo.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTINFO_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=741,
)


_LISTBUCKETSREQUEST = _descriptor.Descriptor(
  name='ListBucketsRequest',
  full_name='yamcs.protobuf.buckets.ListBucketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.buckets.ListBucketsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=781,
)


_LISTBUCKETSRESPONSE = _descriptor.Descriptor(
  name='ListBucketsResponse',
  full_name='yamcs.protobuf.buckets.ListBucketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='buckets', full_name='yamcs.protobuf.buckets.ListBucketsResponse.buckets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=857,
)


_LISTOBJECTSREQUEST = _descriptor.Descriptor(
  name='ListObjectsRequest',
  full_name='yamcs.protobuf.buckets.ListObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.buckets.ListObjectsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucketName', full_name='yamcs.protobuf.buckets.ListObjectsRequest.bucketName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delimiter', full_name='yamcs.protobuf.buckets.ListObjectsRequest.delimiter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='yamcs.protobuf.buckets.ListObjectsRequest.prefix', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=952,
)


_LISTOBJECTSRESPONSE = _descriptor.Descriptor(
  name='ListObjectsResponse',
  full_name='yamcs.protobuf.buckets.ListObjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefixes', full_name='yamcs.protobuf.buckets.ListObjectsResponse.prefixes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects', full_name='yamcs.protobuf.buckets.ListObjectsResponse.objects', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=954,
  serialized_end=1046,
)

_OBJECTINFO_METADATAENTRY.containing_type = _OBJECTINFO
_OBJECTINFO.fields_by_name['metadata'].message_type = _OBJECTINFO_METADATAENTRY
_LISTBUCKETSRESPONSE.fields_by_name['buckets'].message_type = _BUCKETINFO
_LISTOBJECTSRESPONSE.fields_by_name['objects'].message_type = _OBJECTINFO
DESCRIPTOR.message_types_by_name['CreateBucketRequest'] = _CREATEBUCKETREQUEST
DESCRIPTOR.message_types_by_name['DeleteBucketRequest'] = _DELETEBUCKETREQUEST
DESCRIPTOR.message_types_by_name['GetObjectRequest'] = _GETOBJECTREQUEST
DESCRIPTOR.message_types_by_name['DeleteObjectRequest'] = _DELETEOBJECTREQUEST
DESCRIPTOR.message_types_by_name['UploadObjectRequest'] = _UPLOADOBJECTREQUEST
DESCRIPTOR.message_types_by_name['BucketInfo'] = _BUCKETINFO
DESCRIPTOR.message_types_by_name['ObjectInfo'] = _OBJECTINFO
DESCRIPTOR.message_types_by_name['ListBucketsRequest'] = _LISTBUCKETSREQUEST
DESCRIPTOR.message_types_by_name['ListBucketsResponse'] = _LISTBUCKETSRESPONSE
DESCRIPTOR.message_types_by_name['ListObjectsRequest'] = _LISTOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['ListObjectsResponse'] = _LISTOBJECTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateBucketRequest = _reflection.GeneratedProtocolMessageType('CreateBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBUCKETREQUEST,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.CreateBucketRequest)
  })
_sym_db.RegisterMessage(CreateBucketRequest)

DeleteBucketRequest = _reflection.GeneratedProtocolMessageType('DeleteBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBUCKETREQUEST,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.DeleteBucketRequest)
  })
_sym_db.RegisterMessage(DeleteBucketRequest)

GetObjectRequest = _reflection.GeneratedProtocolMessageType('GetObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTREQUEST,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.GetObjectRequest)
  })
_sym_db.RegisterMessage(GetObjectRequest)

DeleteObjectRequest = _reflection.GeneratedProtocolMessageType('DeleteObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOBJECTREQUEST,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.DeleteObjectRequest)
  })
_sym_db.RegisterMessage(DeleteObjectRequest)

UploadObjectRequest = _reflection.GeneratedProtocolMessageType('UploadObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADOBJECTREQUEST,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.UploadObjectRequest)
  })
_sym_db.RegisterMessage(UploadObjectRequest)

BucketInfo = _reflection.GeneratedProtocolMessageType('BucketInfo', (_message.Message,), {
  'DESCRIPTOR' : _BUCKETINFO,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.BucketInfo)
  })
_sym_db.RegisterMessage(BucketInfo)

ObjectInfo = _reflection.GeneratedProtocolMessageType('ObjectInfo', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTINFO_METADATAENTRY,
    '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.ObjectInfo.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _OBJECTINFO,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.ObjectInfo)
  })
_sym_db.RegisterMessage(ObjectInfo)
_sym_db.RegisterMessage(ObjectInfo.MetadataEntry)

ListBucketsRequest = _reflection.GeneratedProtocolMessageType('ListBucketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUCKETSREQUEST,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.ListBucketsRequest)
  })
_sym_db.RegisterMessage(ListBucketsRequest)

ListBucketsResponse = _reflection.GeneratedProtocolMessageType('ListBucketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUCKETSRESPONSE,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.ListBucketsResponse)
  })
_sym_db.RegisterMessage(ListBucketsResponse)

ListObjectsRequest = _reflection.GeneratedProtocolMessageType('ListObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTSREQUEST,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.ListObjectsRequest)
  })
_sym_db.RegisterMessage(ListObjectsRequest)

ListObjectsResponse = _reflection.GeneratedProtocolMessageType('ListObjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTSRESPONSE,
  '__module__' : 'yamcs.protobuf.buckets.buckets_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.buckets.ListObjectsResponse)
  })
_sym_db.RegisterMessage(ListObjectsResponse)


DESCRIPTOR._options = None
_OBJECTINFO_METADATAENTRY._options = None

_BUCKETSAPI = _descriptor.ServiceDescriptor(
  name='BucketsApi',
  full_name='yamcs.protobuf.buckets.BucketsApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1049,
  serialized_end=2055,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListBuckets',
    full_name='yamcs.protobuf.buckets.BucketsApi.ListBuckets',
    index=0,
    containing_service=None,
    input_type=_LISTBUCKETSREQUEST,
    output_type=_LISTBUCKETSRESPONSE,
    serialized_options=_b('\212\222\003\031\n\027/api/buckets/{instance}'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateBucket',
    full_name='yamcs.protobuf.buckets.BucketsApi.CreateBucket',
    index=1,
    containing_service=None,
    input_type=_CREATEBUCKETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003\034\032\027/api/buckets/{instance}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteBucket',
    full_name='yamcs.protobuf.buckets.BucketsApi.DeleteBucket',
    index=2,
    containing_service=None,
    input_type=_DELETEBUCKETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003&\"$/api/buckets/{instance}/{bucketName}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetObject',
    full_name='yamcs.protobuf.buckets.BucketsApi.GetObject',
    index=3,
    containing_service=None,
    input_type=_GETOBJECTREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=_b('\212\222\003<\n:/api/buckets/{instance}/{bucketName}/objects/{objectName*}'),
  ),
  _descriptor.MethodDescriptor(
    name='UploadObject',
    full_name='yamcs.protobuf.buckets.BucketsApi.UploadObject',
    index=4,
    containing_service=None,
    input_type=_UPLOADOBJECTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003B\032;/api/buckets/{instance}/{bucketName}/objects/{objectName**}@\200\200\300\002'),
  ),
  _descriptor.MethodDescriptor(
    name='ListObjects',
    full_name='yamcs.protobuf.buckets.BucketsApi.ListObjects',
    index=5,
    containing_service=None,
    input_type=_LISTOBJECTSREQUEST,
    output_type=_LISTOBJECTSRESPONSE,
    serialized_options=_b('\212\222\003.\n,/api/buckets/{instance}/{bucketName}/objects'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteObject',
    full_name='yamcs.protobuf.buckets.BucketsApi.DeleteObject',
    index=6,
    containing_service=None,
    input_type=_DELETEOBJECTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003<\":/api/buckets/{instance}/{bucketName}/objects/{objectName*}'),
  ),
])
_sym_db.RegisterServiceDescriptor(_BUCKETSAPI)

DESCRIPTOR.services_by_name['BucketsApi'] = _BUCKETSAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/table/table.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.web import rest_pb2 as yamcs_dot_protobuf_dot_web_dot_rest__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/table/table.proto',
  package='yamcs.protobuf.table',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobuf'),
  serialized_pb=_b('\n yamcs/protobuf/table/table.proto\x12\x14yamcs.protobuf.table\x1a\x1byamcs/api/annotations.proto\x1a\x1dyamcs/protobuf/web/rest.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"\xdb\x01\n\x03Row\x12\x34\n\x06\x63olumn\x18\x01 \x03(\x0b\x32$.yamcs.protobuf.table.Row.ColumnInfo\x12,\n\x04\x63\x65ll\x18\x02 \x03(\x0b\x32\x1e.yamcs.protobuf.table.Row.Cell\x1aH\n\nColumnInfo\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x12\n\nprotoClass\x18\x04 \x01(\t\x1a&\n\x04\x43\x65ll\x12\x10\n\x08\x63olumnId\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\'\n\x11TableLoadResponse\x12\x12\n\nrowsLoaded\x18\x01 \x01(\r\"?\n\x0fReadRowsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ols\x18\x03 \x03(\t\"8\n\x11\x45xecuteSqlRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tstatement\x18\x02 \x01(\t\"$\n\x12\x45xecuteSqlResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"%\n\x11ListTablesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"E\n\x12ListTablesResponse\x12/\n\x06tables\x18\x01 \x03(\x0b\x32\x1f.yamcs.protobuf.table.TableInfo\"1\n\x0fGetTableRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"n\n\x13GetTableDataRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ols\x18\x03 \x03(\t\x12\x0b\n\x03pos\x18\x04 \x01(\x03\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\r\n\x05order\x18\x06 \x01(\t\"&\n\x12ListStreamsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"H\n\x13ListStreamsResponse\x12\x31\n\x07streams\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.table.StreamInfo\"2\n\x10GetStreamRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"@\n\nColumnData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\"N\n\nStreamData\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnData\"\x89\x01\n\tTableData\x12;\n\x06record\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.table.TableData.TableRecord\x1a?\n\x0bTableRecord\x12\x30\n\x06\x63olumn\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnData\"\\\n\nColumnInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x32\n\tenumValue\x18\x03 \x03(\x0b\x32\x1f.yamcs.protobuf.table.EnumValue\")\n\tEnumValue\x12\r\n\x05value\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\"\xc6\x02\n\tTableInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x33\n\tkeyColumn\x18\x02 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnInfo\x12\x35\n\x0bvalueColumn\x18\x03 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnInfo\x12\x0e\n\x06script\x18\x04 \x01(\t\x12\x17\n\x0fhistogramColumn\x18\x05 \x03(\t\x12\x15\n\rstorageEngine\x18\x06 \x01(\t\x12\x15\n\rformatVersion\x18\x07 \x01(\x05\x12\x12\n\ntablespace\x18\x08 \x01(\t\x12\x12\n\ncompressed\x18\t \x01(\x08\x12@\n\x10partitioningInfo\x18\n \x01(\x0b\x32&.yamcs.protobuf.table.PartitioningInfo\"\xf5\x01\n\x10PartitioningInfo\x12\x45\n\x04type\x18\x01 \x01(\x0e\x32\x37.yamcs.protobuf.table.PartitioningInfo.PartitioningType\x12\x12\n\ntimeColumn\x18\x02 \x01(\t\x12\x1b\n\x13timePartitionSchema\x18\x03 \x01(\t\x12\x13\n\x0bvalueColumn\x18\x04 \x01(\t\x12\x17\n\x0fvalueColumnType\x18\x05 \x01(\t\";\n\x10PartitioningType\x12\x08\n\x04TIME\x10\x01\x12\t\n\x05VALUE\x10\x02\x12\x12\n\x0eTIME_AND_VALUE\x10\x03\"o\n\nStreamInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnInfo\x12\x0e\n\x06script\x18\x03 \x01(\t\x12\x11\n\tdataCount\x18\x04 \x01(\x03\x32\xca\x07\n\x08TableApi\x12\x8c\x01\n\nExecuteSql\x12\'.yamcs.protobuf.table.ExecuteSqlRequest\x1a(.yamcs.protobuf.table.ExecuteSqlResponse\"+\x8a\x92\x03\'\x1a\"/api/archive/{instance}:executeSql:\x01*\x12\x89\x01\n\x0bListStreams\x12(.yamcs.protobuf.table.ListStreamsRequest\x1a).yamcs.protobuf.table.ListStreamsResponse\"%\x8a\x92\x03!\n\x1f/api/archive/{instance}/streams\x12\x83\x01\n\tGetStream\x12&.yamcs.protobuf.table.GetStreamRequest\x1a .yamcs.protobuf.table.StreamInfo\",\x8a\x92\x03(\n&/api/archive/{instance}/streams/{name}\x12\x85\x01\n\nListTables\x12\'.yamcs.protobuf.table.ListTablesRequest\x1a(.yamcs.protobuf.table.ListTablesResponse\"$\x8a\x92\x03 \n\x1e/api/archive/{instance}/tables\x12\x7f\n\x08GetTable\x12%.yamcs.protobuf.table.GetTableRequest\x1a\x1f.yamcs.protobuf.table.TableInfo\"+\x8a\x92\x03\'\n%/api/archive/{instance}/tables/{name}\x12\x8c\x01\n\x0cGetTableData\x12).yamcs.protobuf.table.GetTableDataRequest\x1a\x1f.yamcs.protobuf.table.TableData\"0\x8a\x92\x03,\n*/api/archive/{instance}/tables/{name}/data\x12\x84\x01\n\x08ReadRows\x12%.yamcs.protobuf.table.ReadRowsRequest\x1a\x19.yamcs.protobuf.table.Row\"4\x8a\x92\x03\x30\x1a./api/archive/{instance}/tables/{name}:readRows0\x01:<\n\nrowsLoaded\x12(.yamcs.protobuf.web.RestExceptionMessage\x18\x64 \x01(\rB\x14\n\x12org.yamcs.protobuf')
  ,
  dependencies=[yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_web_dot_rest__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])


ROWSLOADED_FIELD_NUMBER = 100
rowsLoaded = _descriptor.FieldDescriptor(
  name='rowsLoaded', full_name='yamcs.protobuf.table.rowsLoaded', index=0,
  number=100, type=13, cpp_type=3, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)

_PARTITIONINGINFO_PARTITIONINGTYPE = _descriptor.EnumDescriptor(
  name='PartitioningType',
  full_name='yamcs.protobuf.table.PartitioningInfo.PartitioningType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TIME', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME_AND_VALUE', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1948,
  serialized_end=2007,
)
_sym_db.RegisterEnumDescriptor(_PARTITIONINGINFO_PARTITIONINGTYPE)


_ROW_COLUMNINFO = _descriptor.Descriptor(
  name='ColumnInfo',
  full_name='yamcs.protobuf.table.Row.ColumnInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.table.Row.ColumnInfo.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.Row.ColumnInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.table.Row.ColumnInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protoClass', full_name='yamcs.protobuf.table.Row.ColumnInfo.protoClass', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=326,
)

_ROW_CELL = _descriptor.Descriptor(
  name='Cell',
  full_name='yamcs.protobuf.table.Row.Cell',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columnId', full_name='yamcs.protobuf.table.Row.Cell.columnId', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.table.Row.Cell.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=366,
)

_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='yamcs.protobuf.table.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='yamcs.protobuf.table.Row.column', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell', full_name='yamcs.protobuf.table.Row.cell', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ROW_COLUMNINFO, _ROW_CELL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=366,
)


_TABLELOADRESPONSE = _descriptor.Descriptor(
  name='TableLoadResponse',
  full_name='yamcs.protobuf.table.TableLoadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rowsLoaded', full_name='yamcs.protobuf.table.TableLoadResponse.rowsLoaded', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=407,
)


_READROWSREQUEST = _descriptor.Descriptor(
  name='ReadRowsRequest',
  full_name='yamcs.protobuf.table.ReadRowsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.ReadRowsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.ReadRowsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cols', full_name='yamcs.protobuf.table.ReadRowsRequest.cols', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=409,
  serialized_end=472,
)


_EXECUTESQLREQUEST = _descriptor.Descriptor(
  name='ExecuteSqlRequest',
  full_name='yamcs.protobuf.table.ExecuteSqlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.ExecuteSqlRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statement', full_name='yamcs.protobuf.table.ExecuteSqlRequest.statement', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=530,
)


_EXECUTESQLRESPONSE = _descriptor.Descriptor(
  name='ExecuteSqlResponse',
  full_name='yamcs.protobuf.table.ExecuteSqlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='yamcs.protobuf.table.ExecuteSqlResponse.result', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=568,
)


_LISTTABLESREQUEST = _descriptor.Descriptor(
  name='ListTablesRequest',
  full_name='yamcs.protobuf.table.ListTablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.ListTablesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=607,
)


_LISTTABLESRESPONSE = _descriptor.Descriptor(
  name='ListTablesResponse',
  full_name='yamcs.protobuf.table.ListTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tables', full_name='yamcs.protobuf.table.ListTablesResponse.tables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=678,
)


_GETTABLEREQUEST = _descriptor.Descriptor(
  name='GetTableRequest',
  full_name='yamcs.protobuf.table.GetTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.GetTableRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.GetTableRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=680,
  serialized_end=729,
)


_GETTABLEDATAREQUEST = _descriptor.Descriptor(
  name='GetTableDataRequest',
  full_name='yamcs.protobuf.table.GetTableDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.GetTableDataRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.GetTableDataRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cols', full_name='yamcs.protobuf.table.GetTableDataRequest.cols', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.table.GetTableDataRequest.pos', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.table.GetTableDataRequest.limit', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.table.GetTableDataRequest.order', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=841,
)


_LISTSTREAMSREQUEST = _descriptor.Descriptor(
  name='ListStreamsRequest',
  full_name='yamcs.protobuf.table.ListStreamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.ListStreamsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=881,
)


_LISTSTREAMSRESPONSE = _descriptor.Descriptor(
  name='ListStreamsResponse',
  full_name='yamcs.protobuf.table.ListStreamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streams', full_name='yamcs.protobuf.table.ListStreamsResponse.streams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=955,
)


_GETSTREAMREQUEST = _descriptor.Descriptor(
  name='GetStreamRequest',
  full_name='yamcs.protobuf.table.GetStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.GetStreamRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.GetStreamRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=957,
  serialized_end=1007,
)


_COLUMNDATA = _descriptor.Descriptor(
  name='ColumnData',
  full_name='yamcs.protobuf.table.ColumnData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.ColumnData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.table.ColumnData.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1009,
  serialized_end=1073,
)


_STREAMDATA = _descriptor.Descriptor(
  name='StreamData',
  full_name='yamcs.protobuf.table.StreamData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.table.StreamData.stream', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column', full_name='yamcs.protobuf.table.StreamData.column', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1075,
  serialized_end=1153,
)


_TABLEDATA_TABLERECORD = _descriptor.Descriptor(
  name='TableRecord',
  full_name='yamcs.protobuf.table.TableData.TableRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='yamcs.protobuf.table.TableData.TableRecord.column', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1230,
  serialized_end=1293,
)

_TABLEDATA = _descriptor.Descriptor(
  name='TableData',
  full_name='yamcs.protobuf.table.TableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='yamcs.protobuf.table.TableData.record', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TABLEDATA_TABLERECORD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1156,
  serialized_end=1293,
)


_COLUMNINFO = _descriptor.Descriptor(
  name='ColumnInfo',
  full_name='yamcs.protobuf.table.ColumnInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.ColumnInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.table.ColumnInfo.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumValue', full_name='yamcs.protobuf.table.ColumnInfo.enumValue', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1387,
)


_ENUMVALUE = _descriptor.Descriptor(
  name='EnumValue',
  full_name='yamcs.protobuf.table.EnumValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.table.EnumValue.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.table.EnumValue.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1389,
  serialized_end=1430,
)


_TABLEINFO = _descriptor.Descriptor(
  name='TableInfo',
  full_name='yamcs.protobuf.table.TableInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.TableInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyColumn', full_name='yamcs.protobuf.table.TableInfo.keyColumn', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueColumn', full_name='yamcs.protobuf.table.TableInfo.valueColumn', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script', full_name='yamcs.protobuf.table.TableInfo.script', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='histogramColumn', full_name='yamcs.protobuf.table.TableInfo.histogramColumn', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storageEngine', full_name='yamcs.protobuf.table.TableInfo.storageEngine', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatVersion', full_name='yamcs.protobuf.table.TableInfo.formatVersion', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tablespace', full_name='yamcs.protobuf.table.TableInfo.tablespace', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed', full_name='yamcs.protobuf.table.TableInfo.compressed', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitioningInfo', full_name='yamcs.protobuf.table.TableInfo.partitioningInfo', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1433,
  serialized_end=1759,
)


_PARTITIONINGINFO = _descriptor.Descriptor(
  name='PartitioningInfo',
  full_name='yamcs.protobuf.table.PartitioningInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.table.PartitioningInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeColumn', full_name='yamcs.protobuf.table.PartitioningInfo.timeColumn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timePartitionSchema', full_name='yamcs.protobuf.table.PartitioningInfo.timePartitionSchema', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueColumn', full_name='yamcs.protobuf.table.PartitioningInfo.valueColumn', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueColumnType', full_name='yamcs.protobuf.table.PartitioningInfo.valueColumnType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARTITIONINGINFO_PARTITIONINGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1762,
  serialized_end=2007,
)


_STREAMINFO = _descriptor.Descriptor(
  name='StreamInfo',
  full_name='yamcs.protobuf.table.StreamInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.StreamInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column', full_name='yamcs.protobuf.table.StreamInfo.column', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script', full_name='yamcs.protobuf.table.StreamInfo.script', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataCount', full_name='yamcs.protobuf.table.StreamInfo.dataCount', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2009,
  serialized_end=2120,
)

_ROW_COLUMNINFO.containing_type = _ROW
_ROW_CELL.containing_type = _ROW
_ROW.fields_by_name['column'].message_type = _ROW_COLUMNINFO
_ROW.fields_by_name['cell'].message_type = _ROW_CELL
_LISTTABLESRESPONSE.fields_by_name['tables'].message_type = _TABLEINFO
_LISTSTREAMSRESPONSE.fields_by_name['streams'].message_type = _STREAMINFO
_COLUMNDATA.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_STREAMDATA.fields_by_name['column'].message_type = _COLUMNDATA
_TABLEDATA_TABLERECORD.fields_by_name['column'].message_type = _COLUMNDATA
_TABLEDATA_TABLERECORD.containing_type = _TABLEDATA
_TABLEDATA.fields_by_name['record'].message_type = _TABLEDATA_TABLERECORD
_COLUMNINFO.fields_by_name['enumValue'].message_type = _ENUMVALUE
_TABLEINFO.fields_by_name['keyColumn'].message_type = _COLUMNINFO
_TABLEINFO.fields_by_name['valueColumn'].message_type = _COLUMNINFO
_TABLEINFO.fields_by_name['partitioningInfo'].message_type = _PARTITIONINGINFO
_PARTITIONINGINFO.fields_by_name['type'].enum_type = _PARTITIONINGINFO_PARTITIONINGTYPE
_PARTITIONINGINFO_PARTITIONINGTYPE.containing_type = _PARTITIONINGINFO
_STREAMINFO.fields_by_name['column'].message_type = _COLUMNINFO
DESCRIPTOR.message_types_by_name['Row'] = _ROW
DESCRIPTOR.message_types_by_name['TableLoadResponse'] = _TABLELOADRESPONSE
DESCRIPTOR.message_types_by_name['ReadRowsRequest'] = _READROWSREQUEST
DESCRIPTOR.message_types_by_name['ExecuteSqlRequest'] = _EXECUTESQLREQUEST
DESCRIPTOR.message_types_by_name['ExecuteSqlResponse'] = _EXECUTESQLRESPONSE
DESCRIPTOR.message_types_by_name['ListTablesRequest'] = _LISTTABLESREQUEST
DESCRIPTOR.message_types_by_name['ListTablesResponse'] = _LISTTABLESRESPONSE
DESCRIPTOR.message_types_by_name['GetTableRequest'] = _GETTABLEREQUEST
DESCRIPTOR.message_types_by_name['GetTableDataRequest'] = _GETTABLEDATAREQUEST
DESCRIPTOR.message_types_by_name['ListStreamsRequest'] = _LISTSTREAMSREQUEST
DESCRIPTOR.message_types_by_name['ListStreamsResponse'] = _LISTSTREAMSRESPONSE
DESCRIPTOR.message_types_by_name['GetStreamRequest'] = _GETSTREAMREQUEST
DESCRIPTOR.message_types_by_name['ColumnData'] = _COLUMNDATA
DESCRIPTOR.message_types_by_name['StreamData'] = _STREAMDATA
DESCRIPTOR.message_types_by_name['TableData'] = _TABLEDATA
DESCRIPTOR.message_types_by_name['ColumnInfo'] = _COLUMNINFO
DESCRIPTOR.message_types_by_name['EnumValue'] = _ENUMVALUE
DESCRIPTOR.message_types_by_name['TableInfo'] = _TABLEINFO
DESCRIPTOR.message_types_by_name['PartitioningInfo'] = _PARTITIONINGINFO
DESCRIPTOR.message_types_by_name['StreamInfo'] = _STREAMINFO
DESCRIPTOR.extensions_by_name['rowsLoaded'] = rowsLoaded
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Row = _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), {

  'ColumnInfo' : _reflection.GeneratedProtocolMessageType('ColumnInfo', (_message.Message,), {
    'DESCRIPTOR' : _ROW_COLUMNINFO,
    '__module__' : 'yamcs.protobuf.table.table_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.Row.ColumnInfo)
    })
  ,

  'Cell' : _reflection.GeneratedProtocolMessageType('Cell', (_message.Message,), {
    'DESCRIPTOR' : _ROW_CELL,
    '__module__' : 'yamcs.protobuf.table.table_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.Row.Cell)
    })
  ,
  'DESCRIPTOR' : _ROW,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.Row)
  })
_sym_db.RegisterMessage(Row)
_sym_db.RegisterMessage(Row.ColumnInfo)
_sym_db.RegisterMessage(Row.Cell)

TableLoadResponse = _reflection.GeneratedProtocolMessageType('TableLoadResponse', (_message.Message,), {
  'DESCRIPTOR' : _TABLELOADRESPONSE,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.TableLoadResponse)
  })
_sym_db.RegisterMessage(TableLoadResponse)

ReadRowsRequest = _reflection.GeneratedProtocolMessageType('ReadRowsRequest', (_message.Message,), {
  'DESCRIPTOR' : _READROWSREQUEST,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ReadRowsRequest)
  })
_sym_db.RegisterMessage(ReadRowsRequest)

ExecuteSqlRequest = _reflection.GeneratedProtocolMessageType('ExecuteSqlRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESQLREQUEST,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ExecuteSqlRequest)
  })
_sym_db.RegisterMessage(ExecuteSqlRequest)

ExecuteSqlResponse = _reflection.GeneratedProtocolMessageType('ExecuteSqlResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESQLRESPONSE,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ExecuteSqlResponse)
  })
_sym_db.RegisterMessage(ExecuteSqlResponse)

ListTablesRequest = _reflection.GeneratedProtocolMessageType('ListTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESREQUEST,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ListTablesRequest)
  })
_sym_db.RegisterMessage(ListTablesRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESRESPONSE,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ListTablesResponse)
  })
_sym_db.RegisterMessage(ListTablesResponse)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableDataRequest = _reflection.GeneratedProtocolMessageType('GetTableDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEDATAREQUEST,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.GetTableDataRequest)
  })
_sym_db.RegisterMessage(GetTableDataRequest)

ListStreamsRequest = _reflection.GeneratedProtocolMessageType('ListStreamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTREAMSREQUEST,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ListStreamsRequest)
  })
_sym_db.RegisterMessage(ListStreamsRequest)

ListStreamsResponse = _reflection.GeneratedProtocolMessageType('ListStreamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTREAMSRESPONSE,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ListStreamsResponse)
  })
_sym_db.RegisterMessage(ListStreamsResponse)

GetStreamRequest = _reflection.GeneratedProtocolMessageType('GetStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTREAMREQUEST,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.GetStreamRequest)
  })
_sym_db.RegisterMessage(GetStreamRequest)

ColumnData = _reflection.GeneratedProtocolMessageType('ColumnData', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNDATA,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ColumnData)
  })
_sym_db.RegisterMessage(ColumnData)

StreamData = _reflection.GeneratedProtocolMessageType('StreamData', (_message.Message,), {
  'DESCRIPTOR' : _STREAMDATA,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.StreamData)
  })
_sym_db.RegisterMessage(StreamData)

TableData = _reflection.GeneratedProtocolMessageType('TableData', (_message.Message,), {

  'TableRecord' : _reflection.GeneratedProtocolMessageType('TableRecord', (_message.Message,), {
    'DESCRIPTOR' : _TABLEDATA_TABLERECORD,
    '__module__' : 'yamcs.protobuf.table.table_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.TableData.TableRecord)
    })
  ,
  'DESCRIPTOR' : _TABLEDATA,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.TableData)
  })
_sym_db.RegisterMessage(TableData)
_sym_db.RegisterMessage(TableData.TableRecord)

ColumnInfo = _reflection.GeneratedProtocolMessageType('ColumnInfo', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNINFO,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ColumnInfo)
  })
_sym_db.RegisterMessage(ColumnInfo)

EnumValue = _reflection.GeneratedProtocolMessageType('EnumValue', (_message.Message,), {
  'DESCRIPTOR' : _ENUMVALUE,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.EnumValue)
  })
_sym_db.RegisterMessage(EnumValue)

TableInfo = _reflection.GeneratedProtocolMessageType('TableInfo', (_message.Message,), {
  'DESCRIPTOR' : _TABLEINFO,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.TableInfo)
  })
_sym_db.RegisterMessage(TableInfo)

PartitioningInfo = _reflection.GeneratedProtocolMessageType('PartitioningInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONINGINFO,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.PartitioningInfo)
  })
_sym_db.RegisterMessage(PartitioningInfo)

StreamInfo = _reflection.GeneratedProtocolMessageType('StreamInfo', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINFO,
  '__module__' : 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.StreamInfo)
  })
_sym_db.RegisterMessage(StreamInfo)

yamcs_dot_protobuf_dot_web_dot_rest__pb2.RestExceptionMessage.RegisterExtension(rowsLoaded)

DESCRIPTOR._options = None

_TABLEAPI = _descriptor.ServiceDescriptor(
  name='TableApi',
  full_name='yamcs.protobuf.table.TableApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2123,
  serialized_end=3093,
  methods=[
  _descriptor.MethodDescriptor(
    name='ExecuteSql',
    full_name='yamcs.protobuf.table.TableApi.ExecuteSql',
    index=0,
    containing_service=None,
    input_type=_EXECUTESQLREQUEST,
    output_type=_EXECUTESQLRESPONSE,
    serialized_options=_b('\212\222\003\'\032\"/api/archive/{instance}:executeSql:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ListStreams',
    full_name='yamcs.protobuf.table.TableApi.ListStreams',
    index=1,
    containing_service=None,
    input_type=_LISTSTREAMSREQUEST,
    output_type=_LISTSTREAMSRESPONSE,
    serialized_options=_b('\212\222\003!\n\037/api/archive/{instance}/streams'),
  ),
  _descriptor.MethodDescriptor(
    name='GetStream',
    full_name='yamcs.protobuf.table.TableApi.GetStream',
    index=2,
    containing_service=None,
    input_type=_GETSTREAMREQUEST,
    output_type=_STREAMINFO,
    serialized_options=_b('\212\222\003(\n&/api/archive/{instance}/streams/{name}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListTables',
    full_name='yamcs.protobuf.table.TableApi.ListTables',
    index=3,
    containing_service=None,
    input_type=_LISTTABLESREQUEST,
    output_type=_LISTTABLESRESPONSE,
    serialized_options=_b('\212\222\003 \n\036/api/archive/{instance}/tables'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTable',
    full_name='yamcs.protobuf.table.TableApi.GetTable',
    index=4,
    containing_service=None,
    input_type=_GETTABLEREQUEST,
    output_type=_TABLEINFO,
    serialized_options=_b('\212\222\003\'\n%/api/archive/{instance}/tables/{name}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTableData',
    full_name='yamcs.protobuf.table.TableApi.GetTableData',
    index=5,
    containing_service=None,
    input_type=_GETTABLEDATAREQUEST,
    output_type=_TABLEDATA,
    serialized_options=_b('\212\222\003,\n*/api/archive/{instance}/tables/{name}/data'),
  ),
  _descriptor.MethodDescriptor(
    name='ReadRows',
    full_name='yamcs.protobuf.table.TableApi.ReadRows',
    index=6,
    containing_service=None,
    input_type=_READROWSREQUEST,
    output_type=_ROW,
    serialized_options=_b('\212\222\0030\032./api/archive/{instance}/tables/{name}:readRows'),
  ),
])
_sym_db.RegisterServiceDescriptor(_TABLEAPI)

DESCRIPTOR.services_by_name['TableApi'] = _TABLEAPI

# @@protoc_insertion_point(module_scope)
